Crosses class final

True when the feature geometry crosses the reference geometry.

Inheritance

Constructors

Crosses({String? propertyName, required GmlGeometry geometry})
const

Properties

geometry → GmlGeometry
The reference geometry from the SLD document.
finalinherited
hashCode int
The hash code for this object.
no setteroverride
propertyName String?
Optional geometry property name. Null means the default geometry.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(Map<String, dynamic> properties, {GmlGeometry? geometry}) bool
Evaluates this filter against the given properties and optional feature geometry.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override