PropertyIsEqualTo class final

True when both expressions evaluate to equal values.

Inheritance

Constructors

PropertyIsEqualTo({required Expression expression1, required Expression expression2})
const

Properties

expression1 Expression
Left-hand expression.
finalinherited
expression2 Expression
Right-hand expression.
finalinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(Map<String, dynamic> properties, {GmlGeometry? geometry}) bool
Evaluates this filter against the given properties and optional feature geometry.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override