SelectedChannel class
A selected channel (band) within a raster dataset.
Constructors
- SelectedChannel({required String channelName, ContrastEnhancement? contrastEnhancement})
-
const
Properties
- channelName → String
-
The source channel name (typically a band number like
"1").final - contrastEnhancement → ContrastEnhancement?
-
Optional per-channel contrast enhancement.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override