PropertyIsLike class final
True when expression matches pattern using wildcard/single-char syntax.
Constructors
- PropertyIsLike({required Expression expression, required String pattern, String wildCard = '*', String singleChar = '?', String escapeChar = '\\'})
-
const
Properties
- escapeChar → String
-
Escape character for literal wildcards (default
\).final - expression → Expression
-
The expression to match.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- pattern → String
-
The pattern string containing wildcard and single-char placeholders.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleChar → String
-
Character representing exactly one character (default
?).final - wildCard → String
-
Character representing zero or more characters (default
*).final
Methods
-
evaluate(
Map< String, dynamic> properties, {GmlGeometry? geometry}) → bool -
Evaluates this filter against the given
propertiesand optional featuregeometry.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override