Recode class final
Remaps discrete input values to output values.
- Inheritance
-
- Object
- Expression
- Recode
Constructors
-
Recode({required Expression lookupValue, required List<
RecodeMapping> mappings, Expression? fallbackValue}) -
const
Properties
- fallbackValue → Expression?
-
Optional fallback when no mapping matches.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lookupValue → Expression
-
The expression whose result is looked up.
final
-
mappings
→ List<
RecodeMapping> -
The input→output mappings.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
evaluate(
Map< String, dynamic> properties) → dynamic -
Evaluates this expression against the given
properties.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override