SldIssueSeverity enum
Severity levels for parse and validation issues.
Values
- error → const SldIssueSeverity
-
A problem that prevents meaningful use of the result.
- warning → const SldIssueSeverity
-
A potential problem that does not prevent use but should be reviewed.
- info → const SldIssueSeverity
-
Informational note, e.g. an unsupported vendor extension was encountered.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SldIssueSeverity> - A constant List of the values in this enum, in order of their declaration.